@@ -1,6 +1,10 @@
 import re
-from collections import OrderedDict
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
 from functools import wraps
+import six
 import sqlalchemy as sa
 from sqlalchemy_utils.functions import identity, has_changes
 from .operation import Operation
@@ -164,14 +168,26 @@ class UnitOfWork(object):
         ):
             fetcher = self.manager.fetcher(parent)
             session = sa.orm.object_session(version_obj)
+
+            subquery = fetcher._transaction_id_subquery(
+                version_obj, next_or_prev='prev'
+            )
+            if session.connection().engine.dialect.name == 'mysql':
+                subquery = sa.select(
+                    [self.manager.option(
+                        parent,
+                        'transaction_column_name'
+                    )],
+                    from_obj=[
+                        sa.sql.expression.alias(subquery, name='subquery')
+                    ]
+                )
             return (
                 session.query(version_obj.__class__)
                 .filter(
                     sa.and_(
                         version_obj.__class__.transaction_id ==
-                        fetcher._transaction_id_subquery(
-                            version_obj, next_or_prev='prev'
-                        ),
+                        subquery,
                         *fetcher._pk_correlation_condition(version_obj)
                     )
                 )
@@ -257,7 +273,7 @@ class UnitOfWork(object):
         """
         changed_entities = set()
 
-        for key, value in self.operations.iteritems():
+        for key, value in six.iteritems(self.operations):
             if (
                 not is_modified(value['target']) and
                 value['target'] not in session.deleted
@@ -278,7 +294,7 @@ class UnitOfWork(object):
         for entity in self.changed_entities(session):
             changes = self.manager.transaction_changes_cls(
                 transaction_id=self.current_transaction_id,
-                entity_name=unicode(entity.__name__)
+                entity_name=six.text_type(entity.__name__)
             )
             session.add(changes)
 
@@ -298,7 +314,7 @@ class UnitOfWork(object):
         ):
             for key, value in self.tx_meta.items():
                 if callable(value):
-                    value = unicode(value())
+                    value = six.text_type(value())
                 meta = self.manager.transaction_meta_cls(
                     transaction_id=self.current_transaction_id,
                     key=key,
