@@ -1,6 +1,9 @@
 from copy import copy
+import os
 import warnings
 import sqlalchemy as sa
+from six import PY3
+from pytest import mark
 from sqlalchemy import create_engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
@@ -32,6 +35,7 @@ def log_sql(
     QueryPool.queries.append(statement)
 
 
+@mark.skipif("PY3 and os.environ.get('DB') == 'mysql'")
 class TestCase(object):
     versioning_strategy = 'subquery'
     transaction_column_name = 'transaction_id'
@@ -53,13 +57,20 @@ class TestCase(object):
         flask_versioning_manager.options['versioning'] = False
 
     def setup_method(self, method):
-        # self.engine = create_engine(
-        #     'sqlite:///:memory:'
-        # )
+        adapter = os.environ.get('DB', 'postgres')
+        if adapter == 'postgres':
+            dns = 'postgres://postgres@localhost/sqlalchemy_continuum_test'
+        elif adapter == 'mysql':
+            dns = (
+                'mysql+pymysql://travis@localhost/sqlalchemy_continuum_test'
+                '?use_unicode=0&charset=utf8'
+            )
+        elif adapter == 'sqlite':
+            dns = 'sqlite:///:memory:'
+        else:
+            raise Exception('Unknown driver given: %r' % adapter)
 
-        self.engine = create_engine(
-            'postgres://postgres@localhost/sqlalchemy_continuum_test'
-        )
+        self.engine = create_engine(dns)
         self.connection = self.engine.connect()
         self.Model = declarative_base()
 
