@@ -1,7 +1,7 @@
 from tests import TestCase
 
 
-class TestDelete(TestCase):
+class DeleteTestCase(TestCase):
     def _delete(self):
         article = self.Article()
         article.name = u'Some article'
@@ -12,6 +12,15 @@ class TestDelete(TestCase):
         self.session.delete(article)
         self.session.commit()
 
+    def test_stores_operation_type(self):
+        self._delete()
+        versions = self.session.query(self.ArticleHistory).all()
+        assert versions[1].operation_type == 2
+
+
+class TestDeleteWithoutStoreDataAtDelete(DeleteTestCase):
+    store_data_at_delete = False
+
     def test_creates_versions_on_delete(self):
         self._delete()
         versions = self.session.query(self.ArticleHistory).all()
@@ -19,7 +28,13 @@ class TestDelete(TestCase):
         assert versions[1].name is None
         assert versions[1].content is None
 
-    def test_stores_operation_type(self):
+
+class TestDeleteWithStoreDataAtDelete(DeleteTestCase):
+    store_data_at_delete = True
+
+    def test_creates_versions_on_delete(self):
         self._delete()
         versions = self.session.query(self.ArticleHistory).all()
-        assert versions[1].operation_type == 2
+        assert len(versions) == 2
+        assert versions[1].name == u'Some article'
+        assert versions[1].content == u'Some content'
